
import {
  Bar,
  BarChart,
  Cell,
  Legend,
  Line,
  LineChart,
  Pie,
  PieChart,
  ResponsiveContainer,
  Tooltip,
  XAxis,
  YAxis,
} from "recharts";

export const RiskScoreChart = ({ riskScore }) => {
  // Generate data for the risk score distribution
  const data = [
    { name: "Very Low", range: "0-20", value: 20, color: "#10b981" },
    { name: "Low", range: "21-40", value: 20, color: "#06b6d4" },
    { name: "Moderate", range: "41-60", value: 20, color: "#fbbf24" },
    { name: "High", range: "61-80", value: 20, color: "#fb923c" },
    { name: "Very High", range: "81-100", value: 20, color: "#ef4444" },
  ];

  // Find the segment where riskScore falls
  const activeIndex = Math.min(Math.floor(riskScore / 20), 4);

  return (
    <div className="h-64 w-full">
      <ResponsiveContainer width="100%" height="100%">
        <PieChart>
          <Pie
            data={data}
            cx="50%"
            cy="50%"
            innerRadius={60}
            outerRadius={80}
            paddingAngle={2}
            dataKey="value"
          >
            {data.map((entry, index) => (
              <Cell
                key={`cell-${index}`}
                fill={entry.color}
                stroke="none"
                opacity={index === activeIndex ? 1 : 0.5}
              />
            ))}
          </Pie>
          <Tooltip
            formatter={(value, name, props) => [props.payload.name, props.payload.range]}
            contentStyle={{ background: "rgba(255, 255, 255, 0.9)", border: "none", borderRadius: "8px", boxShadow: "0 4px 12px rgba(0, 0, 0, 0.1)" }}
          />
          <Legend verticalAlign="bottom" height={36} />
        </PieChart>
      </ResponsiveContainer>
    </div>
  );
};

export const PaymentHistoryChart = ({ paymentData }) => {
  return (
    <div className="h-64 w-full">
      <ResponsiveContainer width="100%" height="100%">
        <LineChart
          data={paymentData}
          margin={{ top: 5, right: 30, left: 20, bottom: 5 }}
        >
          <XAxis dataKey="month" />
          <YAxis />
          <Tooltip
            contentStyle={{ background: "rgba(255, 255, 255, 0.9)", border: "none", borderRadius: "8px", boxShadow: "0 4px 12px rgba(0, 0, 0, 0.1)" }}
          />
          <Legend />
          <Line
            type="monotone"
            dataKey="creditCard"
            stroke="#0096FF"
            strokeWidth={2}
            dot={{ r: 3 }}
            activeDot={{ r: 5 }}
            name="Credit Card"
          />
          <Line
            type="monotone"
            dataKey="loan"
            stroke="#10b981"
            strokeWidth={2}
            dot={{ r: 3 }}
            activeDot={{ r: 5 }}
            name="Loan EMI"
          />
        </LineChart>
      </ResponsiveContainer>
    </div>
  );
};

export const SpendingTrendChart = ({ spendingData }) => {
  return (
    <div className="h-64 w-full">
      <ResponsiveContainer width="100%" height="100%">
        <BarChart
          data={spendingData}
          margin={{ top: 5, right: 30, left: 20, bottom: 5 }}
        >
          <XAxis dataKey="month" />
          <YAxis />
          <Tooltip
            contentStyle={{ background: "rgba(255, 255, 255, 0.9)", border: "none", borderRadius: "8px", boxShadow: "0 4px 12px rgba(0, 0, 0, 0.1)" }}
          />
          <Legend />
          <Bar
            dataKey="income"
            fill="#0096FF"
            radius={[4, 4, 0, 0]}
            name="Income"
          />
          <Bar
            dataKey="spending"
            fill="#fbbf24"
            radius={[4, 4, 0, 0]}
            name="Spending"
          />
        </BarChart>
      </ResponsiveContainer>
    </div>
  );
};

export const ComparisonChart = ({ comparisonData }) => {
  return (
    <div className="h-64 w-full">
      <ResponsiveContainer width="100%" height="100%">
        <BarChart
          data={comparisonData}
          margin={{ top: 5, right: 30, left: 20, bottom: 5 }}
          layout="vertical"
        >
          <XAxis type="number" />
          <YAxis dataKey="name" type="category" width={150} />
          <Tooltip
            contentStyle={{ background: "rgba(255, 255, 255, 0.9)", border: "none", borderRadius: "8px", boxShadow: "0 4px 12px rgba(0, 0, 0, 0.1)" }}
          />
          <Legend />
          <Bar
            dataKey="client"
            fill="#0096FF"
            radius={[0, 4, 4, 0]}
            name="Client"
          />
          <Bar
            dataKey="average"
            fill="#94a3b8"
            radius={[0, 4, 4, 0]}
            name="Industry Average"
          />
        </BarChart>
      </ResponsiveContainer>
    </div>
  );
};
